@@ -57,6 +57,45 @@ static void cleanup()
 }
 
 #ifdef HILDON_HAS_APP_MENU
+
+void
+orientation_enable_accelerators(osso_context_t *ctx)
+{
+	AppData *app_data = app_data_get();
+
+	if (app_data->accelerators == TRUE) {
+		return;
+	}
+
+	/* TODO: Replace string "req_accelerometer_enable" with constant once we switched to final SDK */
+	if (osso_rpc_run_system(ctx, MCE_SERVICE, MCE_REQUEST_PATH,
+			MCE_REQUEST_IF,	"req_accelerometer_enable", NULL, DBUS_TYPE_INVALID) == OSSO_OK) {
+		g_printerr("INFO: Accelerometers enabled\n");
+		app_data->accelerators = TRUE;
+	} else {
+		g_printerr("WARN: Cannot enable accelerometers\n");
+	}
+}
+
+void
+orientation_disable_accelerators(osso_context_t *ctx)
+{
+	AppData *app_data = app_data_get();
+
+	if (app_data->accelerators == FALSE) {
+		return;
+	}
+
+	/* TODO: Replace string "req_accelerometer_disable" with constant once we switched to final SDK */
+	if (osso_rpc_run_system(ctx, MCE_SERVICE, MCE_REQUEST_PATH,
+			MCE_REQUEST_IF,	"req_accelerometer_disable", NULL, DBUS_TYPE_INVALID) == OSSO_OK) {
+		g_printerr("INFO: Accelerometers disabled\n");
+		app_data->accelerators = FALSE;
+	} else {
+		g_printerr("WARN: Cannot disable accelerometers\n");
+	}
+}
+
 static void
 set_orientation(const gchar* orientation)
 {
@@ -136,8 +175,20 @@ dbus_is_portrait_mode(osso_context_t* ctx)
 
 	return result;
 }
-#endif
 
+static void
+on_window_is_topmost_changed (HildonProgram *prog, GParamSpec *prop, gpointer data)
+{
+	osso_context_t *ctx = (osso_context_t*) data;
+
+	if (hildon_program_get_is_topmost(prog)) {
+		orientation_enable_accelerators(ctx);
+	} else {
+		orientation_disable_accelerators(ctx);
+	}
+}
+
+#endif
 
 
 int
@@ -171,10 +222,20 @@ main (int argc, char *argv[])
       return OSSO_ERROR;
   }
 
+  /* Create the Hildon program and setup the title */
+  program = HILDON_PROGRAM(hildon_program_get_instance());
+  g_set_application_name("Conboy");
+
   /* Get the DBus connection */
   DBusConnection *con = osso_get_sys_dbus_connection(osso_context);
 
 #ifdef HILDON_HAS_APP_MENU
+  /* Connect to is-topmost signal */
+  g_signal_connect(program, "notify::is-topmost", G_CALLBACK(on_window_is_topmost_changed), osso_context);
+
+  /* Enable accelerators */
+  orientation_enable_accelerators(osso_context);
+
   /* Get current orientation from DBus and save into app_data */
   app_data->portrait = dbus_is_portrait_mode(osso_context);
 
@@ -186,11 +247,6 @@ main (int argc, char *argv[])
 #endif
 
 
-
-  /* Create the Hildon program and setup the title */
-  program = HILDON_PROGRAM(hildon_program_get_instance());
-  g_set_application_name("Conboy");
-
   if (settings_load_startup_window() == SETTINGS_STARTUP_WINDOW_NOTE) {
 	  /* Get the most recent note. If there is none, create new. */
 	  note = note_list_store_get_latest(app_data->note_store);
